==> fastor_app_ui_widget-1.3.2.tar.gz: lib/resource/template/TabBar/simple/TabBarFastor.dart <==
import 'package:fastor_app_ui_widget/fastor_app_ui_widget.dart';
import 'package:fastor_app_ui_widget/resource/template/TabBar/simple/ItemTabBarFastor.dart';
import 'package:flutter/material.dart';

typedef TabBarPressedFastor = Function(int position, String title );

class TabBarFastor extends StatefulWidget {

  double width;
  double height;
  double widthItemTab = 0;
  List<String> names;
  Color  indicatorColor; //colorActive;
  Color unselectedLabelColor;
  TabBarPressedFastor pressed;
  int? initialSelectIndex  = 0;
  double? fontSize;
  String? fontFamily;
  double? spaceBetweenLabelAndUnderline;
  Decoration? decorationTabBar;
  double? heightUnderline ;

  TabBarFastor( {
    required this.width,
    required this.height,
    required this.names,
    required this.indicatorColor,
    required this.unselectedLabelColor,
    required this.pressed,
    this.initialSelectIndex,
    this.fontSize,
    this.fontFamily,
    this.spaceBetweenLabelAndUnderline,
    this.decorationTabBar,
    this.heightUnderline
  }) {
    calculateItemTabWidth();
    initDefaultValue();
  }


  void calculateItemTabWidth(){
    int sizeTabs = names.length;
    double sizeDouble =  double.parse( sizeTabs.toString() + ".0");
    widthItemTab = width / sizeDouble;
  }

  void initDefaultValue(){
    initialSelectIndex ??= 0;
    heightUnderline ??= 1;
  }


  @override
  TabBarFastorState createState()  => TabBarFastorState();

}

class TabBarFastorState extends State<TabBarFastor>  {

  int selectedIndex = 0 ;

  @override
  void initState() {
    selectedIndex = widget.initialSelectIndex!;
    super.initState();

  }

  @override
  Widget build(BuildContext context) {
    return Container(
      width: widget.width,
      height: widget.height,
      decoration: widget.decorationTabBar,
      child: contentUIBars(),
    );
  }

  //------------------------------------------------------------ tab bar

  Widget contentUIBars(){
    return RowScrollFastor(children:  childrenTabs());
  }


  List<Widget> childrenTabs(){
    List<Widget> ls = [];
    int index = 0;
    widget.names.forEach(( singleName) {
      Widget tab = ItemTabBarFastor(singleName, index );
      ls.add( tab);
      index += 1;
    });
    return ls;
  }


}

==> fastor_app_ui_widget-1.3.36.tar.gz: lib/resource/template/TabBar/simple/TabBarFastor.dart <==
import 'package:fastor_app_ui_widget/fastor_app_ui_widget.dart';
import 'package:fastor_app_ui_widget/resource/template/TabBar/simple/ItemTabBarFastor.dart';
import 'package:flutter/material.dart';

typedef TabBarPressedFastor = Function(int position, String title );

class TabBarFastor extends StatefulWidget {

  double width;
  double height;
  double widthItemTab = 0;
  List<String> names;
  Color  indicatorColor; //colorActive;
  Color unselectedLabelColor;
  TabBarPressedFastor pressed;
  int? initialSelectIndex  = 0;
  double? fontSize;
  String? fontFamily;
  double? spaceBetweenLabelAndUnderline;
  Decoration? decorationTabBar;
  double? heightUnderline ;
  bool? underlineShownBelowAllTabs;

  TabBarFastor( {
    required this.width,
    required this.height,
    required this.names,
    required this.indicatorColor,
    required this.unselectedLabelColor,
    required this.pressed,
    this.initialSelectIndex,
    this.fontSize,
    this.fontFamily,
    this.spaceBetweenLabelAndUnderline,
    this.decorationTabBar,
    this.heightUnderline,
    this.underlineShownBelowAllTabs
  }) {
    calculateItemTabWidth();
    initDefaultValue();
  }


  void calculateItemTabWidth(){
    int sizeTabs = names.length;
    double sizeDouble =  double.parse( sizeTabs.toString() + ".0");
    widthItemTab = width / sizeDouble;
  }

  void initDefaultValue(){
    initialSelectIndex ??= 0;
    heightUnderline ??= 1;
    underlineShownBelowAllTabs ??= false;
  }


  @override
  TabBarFastorState createState()  => TabBarFastorState();

}

class TabBarFastorState extends State<TabBarFastor>  {

  int selectedIndex = 0 ;

  @override
  void initState() {
    selectedIndex = widget.initialSelectIndex!;
    super.initState();

  }

  @override
  Widget build(BuildContext context) {
    return Container(
      width: widget.width,
      height: widget.height,
      decoration: widget.decorationTabBar,
      child: contentUIBars(),
    );
  }

  //------------------------------------------------------------ tab bar

  Widget contentUIBars(){
    return RowScrollFastor(children:  childrenTabs());
  }


  List<Widget> childrenTabs(){
    List<Widget> ls = [];
    int index = 0;
    widget.names.forEach(( singleName) {
      Widget tab = ItemTabBarFastor(singleName, index );
      ls.add( tab);
      index += 1;
    });
    return ls;
  }


}
